use serde::Deserialize;
use std::fs;
use toml;

#[derive(Debug, Deserialize)]
pub struct Config {
    pub mongodb: MongoConfig,
}

#[derive(Debug, Deserialize)]
pub struct MongoConfig {
    pub uri: String,
    pub database: String,
    pub full_collection: String,
    pub partial_collection: String,
    pub batch_size: usize,
}

impl Config {
    pub fn load() -> Result<Self, Box<dyn std::error::Error>> {
        // Construct the path to ~/.config/pwnwriter/config.toml
        let mut config_path = dirs::home_dir().ok_or("Cannot determine home directory")?;
        config_path.push(".config/pwnwriter/config.toml");

        // Read the configuration file
        let contents = fs::read_to_string(config_path)?;
        let config: Config = toml::from_str(&contents)?;
        Ok(config)
    }
}
