use mongodb::{options::ClientOptions, Client, Collection};
use crate::config::Config;

#[derive(Clone)]
pub struct Database {
    pub full_coll: Collection<mongodb::bson::Document>,
    pub partial_coll: Collection<mongodb::bson::Document>,
}

impl Database {
    pub async fn connect(config: &Config) -> Result<Self, mongodb::error::Error> {
        let client_options = ClientOptions::parse(&config.mongodb.uri).await?;
        let client = Client::with_options(client_options)?;
        let db = client.database(&config.mongodb.database);

        Ok(Database {
            full_coll: db.collection(&config.mongodb.full_collection),
            partial_coll: db.collection(&config.mongodb.partial_collection),
        })
    }

    pub async fn insert_many(&self, records: Vec<mongodb::bson::Document>, full: bool) -> Result<(), mongodb::error::Error> {
        let collection = if full { &self.full_coll } else { &self.partial_coll };
        collection.insert_many(records).await?;
        Ok(())
    }
}
