mod config;
mod parser;
mod database;
mod file_handler;
mod progress;
mod utils;

use std::env;
//use std::sync::Arc;
use tokio;
//use tokio::sync::Mutex;
use crate::config::Config;
use crate::database::Database;
use crate::file_handler::process_file;
//use crate::progress::ProgressTracker;
use crate::utils::get_line_count;

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>>{
    // Read command-line arguments
    let args: Vec<String> = env::args().collect();
    if args.len() != 2 {
        eprintln!("Usage: ./pwnWriter <input_file>");
        std::process::exit(1);
    }
    let input_file = &args[1];
    let total_lines = get_line_count(input_file)?;
    //let progress = Arc::new(Mutex::new(ProgressTracker::new(Some(total_lines))));
    println!("Total lines in {}: {}", input_file, total_lines);

    // Load configuration
    let config = match Config::load() {
        Ok(cfg) => cfg,
        Err(e) => {
            eprintln!("Error loading configuration: {}", e);
            std::process::exit(1);
        }
    };

    // Initialize MongoDB
    let db = match Database::connect(&config).await {
        Ok(database) => database,
        Err(e) => {
            eprintln!("Error connecting to MongoDB: {}", e);
            std::process::exit(1);
        }
    };

    // Process the input file
    if let Err(e) = process_file(input_file, &db, &config, total_lines).await {
        eprintln!("Error processing file: {}", e);
        std::process::exit(1);
    }

    Ok(())
}
