#[derive(Debug)]
pub enum ParsedRecord {
    Full { url: String, username: String, password: String },
    Partial { username: String, password: String },
    Malformed(String),
}

pub fn parse_line(line: &str) -> ParsedRecord {
    let parts: Vec<&str> = line.split(':').collect();
    match parts.len() {
        3 => ParsedRecord::Full {
            url: normalize_url(parts[0]),
            username: parts[1].to_string(),
            password: parts[2].to_string(),
        },
        2 => ParsedRecord::Partial {
            username: parts[0].to_string(),
            password: parts[1].to_string(),
        },
        _ => ParsedRecord::Malformed(line.to_string()),
    }
}

fn normalize_url(url: &str) -> String {
    if url.starts_with("http://") || url.starts_with("https://") {
        url.to_string()
    } else {
        format!("https://{}", url)
    }
}
